import * as _zag_js_anatomy from '@zag-js/anatomy';
import { RequiredBy, PropTypes, DirectionProperty, CommonProperties, Orientation, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';

declare const anatomy: _zag_js_anatomy.AnatomyInstance<"root" | "item">;

interface ValueChangeDetails {
    value: string[];
}
type ElementIds = Partial<{
    root: string;
    toggle(value: string): string;
}>;
interface PublicContext extends DirectionProperty, CommonProperties {
    /**
     * The ids of the elements in the toggle. Useful for composition.
     */
    ids?: ElementIds;
    /**
     * Whether the toggle is disabled.
     */
    disabled?: boolean;
    /**
     * The values of the toggles in the group.
     */
    value: string[];
    /**
     * Function to call when the toggle is clicked.
     */
    onValueChange?: (details: ValueChangeDetails) => void;
    /**
     * Whether to loop focus inside the toggle group.
     */
    loop: boolean;
    /**
     *  Whether to use roving tab index to manage focus.
     */
    rovingFocus?: boolean;
    /**
     * The orientation of the toggle group.
     */
    orientation: Orientation;
    /**
     * Whether to allow multiple toggles to be selected.
     */
    multiple?: boolean;
}
type UserDefinedContext = RequiredBy<PublicContext, "id">;
type ComputedContext = Readonly<{
    currentLoop: boolean;
}>;
interface PrivateContext {
}
interface MachineContext extends PublicContext, PrivateContext, ComputedContext {
}
interface MachineState {
    value: "idle" | "focused";
}
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
interface ItemProps {
    value: string;
    disabled?: boolean;
}
interface ItemState {
    id: string;
    isDisabled: boolean;
    isPressed: boolean;
    isFocused: boolean;
}
interface MachineApi<T extends PropTypes = PropTypes> {
    /**
     * The value of the toggle group.
     */
    value: string[];
    /**
     * Function to set the value of the toggle group.
     */
    setValue: (values: string[]) => void;
    /**
     * Returns the state of the toggle item.
     */
    getItemState(props: ItemProps): ItemState;
    rootProps: T["element"];
    getItemProps(props: ItemProps): T["button"];
}

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

declare const props: ("multiple" | "disabled" | "dir" | "id" | "loop" | "value" | "orientation" | "ids" | "onValueChange" | "rovingFocus" | "getRootNode")[];
declare const splitProps: <Props extends Partial<UserDefinedContext>>(props: Props) => [Partial<UserDefinedContext>, Omit<Props, "multiple" | "disabled" | "dir" | "id" | "loop" | "value" | "orientation" | "ids" | "onValueChange" | "rovingFocus" | "getRootNode">];
declare const itemProps: (keyof ItemProps)[];
declare const splitItemProps: <Props extends ItemProps>(props: Props) => [ItemProps, Omit<Props, keyof ItemProps>];

export { type MachineApi as Api, type UserDefinedContext as Context, type ElementIds, type ItemProps, type ItemState, type ValueChangeDetails, anatomy, connect, itemProps, machine, props, splitItemProps, splitProps };
